package com.yanzhu.jh.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectVideoConfig;
import com.yanzhu.jh.project.service.ISurProjectVideoConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 视频配置Controller
 * 
 * @author JiangYuQi
 * @date 2023-08-25
 */
@RestController
@RequestMapping("/project/videoConfig")
public class SurProjectVideoConfigController extends BaseController
{
    @Autowired
    private ISysDeptService sysDeptService;

    @Autowired
    private ISurProjectVideoConfigService surProjectVideoConfigService;

    /**
     * 查询视频配置列表
     */
    @PreAuthorize("@ss.hasPermi('project:videoConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurProjectVideoConfig surProjectVideoConfig)
    {
        startPage();
        surProjectVideoConfig.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(surProjectVideoConfig.getNowRole())){
            surProjectVideoConfig.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            surProjectVideoConfig.setNowDept(Convert.toStr(getDeptId()));
        }
        surProjectVideoConfig.setNowUser(Convert.toStr(getUserId()));
        List<SurProjectVideoConfig> list = surProjectVideoConfigService.selectSurProjectVideoConfigList(surProjectVideoConfig);
        return getDataTable(list);
    }

    /**
     * 导出视频配置列表
     */
    @PreAuthorize("@ss.hasPermi('project:videoConfig:export')")
    @Log(title = "视频配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectVideoConfig surProjectVideoConfig)
    {
        surProjectVideoConfig.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(surProjectVideoConfig.getNowRole())){
            surProjectVideoConfig.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            surProjectVideoConfig.setNowDept(Convert.toStr(getDeptId()));
        }
        surProjectVideoConfig.setNowUser(Convert.toStr(getUserId()));
        List<SurProjectVideoConfig> list = surProjectVideoConfigService.selectSurProjectVideoConfigList(surProjectVideoConfig);
        ExcelUtil<SurProjectVideoConfig> util = new ExcelUtil<SurProjectVideoConfig>(SurProjectVideoConfig.class);
        util.exportExcel(response, list, "视频配置数据");
    }

    /**
     * 获取视频配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:videoConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectVideoConfigService.selectSurProjectVideoConfigById(id));
    }

    /**
     * 新增视频配置
     */
    @PreAuthorize("@ss.hasPermi('project:videoConfig:add')")
    @Log(title = "视频配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurProjectVideoConfig surProjectVideoConfig)
    {
        return toAjax(surProjectVideoConfigService.insertSurProjectVideoConfig(surProjectVideoConfig));
    }

    /**
     * 修改视频配置
     */
    @PreAuthorize("@ss.hasPermi('project:videoConfig:edit')")
    @Log(title = "视频配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectVideoConfig surProjectVideoConfig)
    {
        return toAjax(surProjectVideoConfigService.updateSurProjectVideoConfig(surProjectVideoConfig));
    }

    /**
     * 删除视频配置
     */
    @PreAuthorize("@ss.hasPermi('project:videoConfig:remove')")
    @Log(title = "视频配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectVideoConfigService.deleteSurProjectVideoConfigByIds(ids));
    }
}
